@@ -48,6 +48,7 @@ def plot_4D(
     is_grid=False,
     grid_xlw=None,
     grid_ylw=None,
+    marker_color="k",
 ):
     """Plots a 4D graph
 
@@ -130,7 +131,7 @@ def plot_4D(
         is_show_fig = True if fig is None else False
 
     # Set if figure is 3D
-    if type_plot != "scatter":
+    if "scatter" not in type_plot:
         is_3d = True
     else:
         is_3d = False
@@ -200,6 +201,7 @@ def plot_4D(
             l.set_family(font_name)
         if xticks is not None:
             ax.xaxis.set_ticks(xticks)
+            plt.xticks(rotation=90, ha="center", va="top")
         if xticklabels is not None:
             ax.set_xticklabels(xticklabels, rotation=90)
         if yticks is not None:
@@ -208,14 +210,34 @@ def plot_4D(
             ax.set_yticklabels(yticklabels)
         if annotations is not None:
             for i, txt in enumerate(annotations):
-                if Zdata[i] > z_max * annotation_threshold and txt is not None:
+                if Zdata[i] > annotation_threshold and txt is not None:
                     ax.annotate(
-                        str(txt) + " [Hz]",
+                        txt,
                         (Xdata[i], Ydata[i]),
                         rotation=45,
                         family=font_name,
                     )
 
+    elif type_plot == "scatterX":
+        c = ax.scatter(
+            Xdata,
+            Ydata,
+            s=50 * Zdata,
+            color=marker_color,
+            marker="x",
+            picker=True,
+            pickradius=5,
+        )
+        if xticks is not None:
+            ax.xaxis.set_ticks(xticks)
+            plt.xticks(rotation=90, ha="center", va="top")
+        if xticklabels is not None:
+            ax.set_xticklabels(xticklabels, rotation=90)
+        if yticks is not None:
+            ax.yaxis.set_ticks(yticks)
+        if yticklabels is not None:
+            ax.set_yticklabels(yticklabels)
+
     ax.set_xlabel(xlabel)
     ax.set_ylabel(ylabel)
     ax.set_xlim([x_min, x_max])
