@@ -18,8 +18,6 @@ def plot_2D_Data_Animated(
     data_list=[],
     legend_list=[],
     color_list=None,
-    curve_colors=None,
-    phase_colors=None,
     linestyles=None,
     linewidth_list=[2],
     save_path=None,
@@ -183,8 +181,6 @@ def plot_2D_Data_Animated(
                 data_list=data_list,
                 legend_list=legend_list,
                 color_list=color_list,
-                curve_colors=curve_colors,
-                phase_colors=phase_colors,
                 linestyles=linestyles,
                 linewidth_list=linewidth_list,
                 save_path=save_path,
